# Traffic scene renderer

This traffic scene renderer enables drawing top-view overviews of traffic constellations. 
This drawings can be printed on screen using `matplotlib` and exported to images or `tikz` files that can be rendered with LaTeX to create vector-based drawings of the traffic scenes.

## Installation



## Usage


# Development
